--[[
Copyright 2012 João Cardoso
PetTracker is distributed under the terms of the GNU General Public License (Version 3).
As a special exception, the copyright holders of this addon do not give permission to
redistribute and/or modify it.

This addon is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with the addon. If not, see <http://www.gnu.org/licenses/gpl-3.0.txt>.

This file is part of PetTracker.
--]]

local ADDON, Addon = ...
local Tracker = Addon:NewModule('ZoneTracker', Addon.List())
local Title, Bar = Addon.Line(Tracker), Addon.ProgressBar(Tracker)

local DarkYellow = PASSIVE_SPELL_FONT_COLOR
local Journal = Addon.Journal


--[[ Startup ]]--

function Tracker:Startup()
	self.Anchor = Bar
	self:RegisterEvent('PET_JOURNAL_LIST_UPDATE')
	self:SetScript('OnEvent', function()
		WatchFrame_Update()
	end)
	
	Bar:SetPoint('TOPLEFT', Title, 'BOTTOMLEFT', 0, -2)
	Title.text:SetTextColor(DarkYellow.r, DarkYellow.g, DarkYellow.b)
	Title.text:SetText('Battle Pets')
	
	WatchFrame_AddObjectiveHandler(function(parent, anchor, _, width)
		self:Reset()
		
		if PetTracker_NoTracking then
			self:Hide()
		else
			self:SetWidth(width)
			self:SetParent(parent)
			self:DisplayAt(anchor)
			self:Show()
		end
		
		return self:Last(), 0, self:Count(), 0
	end)
end


--[[ Display ]]--

function Tracker:DisplayAt(anchor)
	local progress = Journal:GetCurrentProgress()
	local point = anchor and 'BOTTOMLEFT' or 'TOPLEFT'
	local at = anchor or self:GetParent()
	
	Title:SetPoint('TOPLEFT', at, point, 2, -4)
	Bar:SetWidth(self:GetWidth() - 5)
	Bar:SetProgress(progress)

	for quality = 0, 4 do
		for i, specie in ipairs(progress[quality]) do
			self:AddSpecie(quality, specie)
		end
	end
end

function Tracker:AddSpecie(quality, specie)
	local sourceIcon = Journal:GetSourceIcon(specie)
	if sourceIcon then
		local r,g,b = Addon:GetQualityColor(quality)
		local name, icon = Journal:GetInfo(specie)
	
		local line = self:NewLine()
		line.subIcon:SetTexture(sourceIcon)
		line.icon:SetTexture(icon)
		line.text:SetTextColor(r,g,b)
		line.text:SetText(name)
	end
end